@@ -36,6 +36,7 @@ struct DownloadConfig
     unsigned int iInclude;
     unsigned int iGalaxyPlatform;
     unsigned int iGalaxyLanguage;
+    unsigned int iGalaxyArch;
 
     bool bRemoteXML;
     bool bCover;
@@ -65,7 +66,7 @@ class GalaxyConfig
         bool isExpired()
         {
             std::unique_lock<std::mutex> lock(m);
-            bool bExpired = false;
+            bool bExpired = true; // assume that token is expired
             intmax_t time_now = time(NULL);
             if (this->token_json.isMember("expires_at"))
                 bExpired = (time_now > this->token_json["expires_at"].asLargestInt());
@@ -74,14 +75,20 @@ class GalaxyConfig
 
         std::string getAccessToken()
         {
+            std:: string access_token;
             std::unique_lock<std::mutex> lock(m);
-            return this->token_json["access_token"].asString();
+            if (this->token_json.isMember("access_token"))
+                access_token = this->token_json["access_token"].asString();
+            return access_token;
         }
 
         std::string getRefreshToken()
         {
+            std::string refresh_token;
             std::unique_lock<std::mutex> lock(m);
-            return this->token_json["refresh_token"].asString();
+            if (this->token_json.isMember("refresh_token"))
+                refresh_token = this->token_json["refresh_token"].asString();
+            return refresh_token;
         }
 
         Json::Value getJSON()
@@ -180,6 +187,7 @@ struct CurlConfig
     bool bVerbose;
     std::string sCACertPath;
     std::string sCookiePath;
+    std::string sUserAgent;
     long int iTimeout;
     curl_off_t iDownloadRate;
 };
@@ -276,6 +284,7 @@ class Config
         unsigned int iThreads;
         int iWait;
         size_t iChunkSize;
+        int iProgressInterval;
 };
 
 #endif // CONFIG_H__
