@@ -90,7 +90,7 @@ class Downloader
         std::deque< std::pair<time_t, uintmax_t> > TimeAndSize;
         void saveGalaxyJSON();
 
-        void galaxyInstallGame(const std::string& product_id, int build_index = -1);
+        void galaxyInstallGame(const std::string& product_id, int build_index = -1, const unsigned int& iGalaxyArch = GlobalConstants::ARCH_X64);
         void galaxyShowBuilds(const std::string& product_id, int build_index = -1);
     protected:
     private:
@@ -122,6 +122,8 @@ class Downloader
         static size_t writeData(void *ptr, size_t size, size_t nmemb, FILE *stream);
         static size_t readData(void *ptr, size_t size, size_t nmemb, FILE *stream);
 
+        std::vector<std::string> galaxyGetOrphanedFiles(const std::vector<galaxyDepotItem>& items, const std::string& install_path);
+
         Website *gogWebsite;
         API *gogAPI;
         galaxyAPI *gogGalaxy;
