@@ -12,7 +12,7 @@
 
 namespace GlobalConstants
 {
-    const int GAMEDETAILS_CACHE_VERSION = 2;
+    const int GAMEDETAILS_CACHE_VERSION = 3;
     const int ZLIB_WINDOW_SIZE = 15;
 
     struct optionsStruct {const unsigned int id; const std::string code; const std::string str; const std::string regexp;};
@@ -41,6 +41,8 @@ namespace GlobalConstants
     const unsigned int LANGUAGE_PT_BR = 1 << 19;
     const unsigned int LANGUAGE_SK = 1 << 20;
     const unsigned int LANGUAGE_BL = 1 << 21;
+    const unsigned int LANGUAGE_UK = 1 << 22;
+    const unsigned int LANGUAGE_ES_419 = 1 << 23;
 
     const std::vector<optionsStruct> LANGUAGES =
     {
@@ -65,7 +67,9 @@ namespace GlobalConstants
         { LANGUAGE_FI, "fi", "Finnish"   , "fi|fin|finnish"        },
         { LANGUAGE_PT_BR, "br", "Brazilian Portuguese", "br|pt_br|pt-br|ptbr|brazilian_portuguese" },
         { LANGUAGE_SK, "sk", "Slovak"    , "sk|slk|slo|slovak"     },
-        { LANGUAGE_BL, "bl", "Bulgarian" , "bl|bg|bul|bulgarian"   }
+        { LANGUAGE_BL, "bl", "Bulgarian" , "bl|bg|bul|bulgarian"   },
+        { LANGUAGE_UK, "uk", "Ukrainian" , "uk|ukr|ukrainian"      },
+        { LANGUAGE_ES_419, "es_mx", "Spanish (Latin American)", "es_mx|es-mx|esmx|es-419|spanish_latin_american" }
     };
 
     // Platform constants
@@ -79,6 +83,16 @@ namespace GlobalConstants
         { PLATFORM_MAC,     "mac",   "Mac"     , "m|mac|osx"     },
         { PLATFORM_LINUX,   "linux", "Linux"   , "l|lin|linux"   }
     };
+
+    // Galaxy platform arch
+    const unsigned int ARCH_X86 = 1 << 0;
+    const unsigned int ARCH_X64 = 1 << 1;
+
+    const std::vector<optionsStruct> GALAXY_ARCHS =
+    {
+        { ARCH_X86, "32", "32-bit", "32|x86|32bit|32-bit" },
+        { ARCH_X64, "64", "64-bit", "64|x64|64bit|64-bit" }
+    };
 }
 
 #endif // GLOBALCONSTANTS_H_INCLUDED
