@@ -66,11 +66,12 @@ namespace Util
     std::string getConfigHome();
     std::string getCacheHome();
     std::vector<std::string> tokenize(const std::string& str, const std::string& separator = ",");
-    unsigned int getOptionValue(const std::string& str, const std::vector<GlobalConstants::optionsStruct>& options);
+    unsigned int getOptionValue(const std::string& str, const std::vector<GlobalConstants::optionsStruct>& options, const bool& bAllowStringToIntConversion = true);
     std::string getOptionNameString(const unsigned int& value, const std::vector<GlobalConstants::optionsStruct>& options);
     void parseOptionString(const std::string &option_string, std::vector<unsigned int> &priority, unsigned int &type, const std::vector<GlobalConstants::optionsStruct>& options);
     std::string getLocalFileHash(const std::string& xml_dir, const std::string& filepath, const std::string& gamename = std::string());
     void shortenStringToTerminalWidth(std::string& str);
+    std::string getJsonUIntValueAsString(const Json::Value& json);
 
     template<typename ... Args> std::string formattedString(const std::string& format, Args ... args)
     {
