@@ -482,7 +482,7 @@ std::vector<std::string> Util::tokenize(const std::string& str, const std::strin
     return tokens;
 }
 
-unsigned int Util::getOptionValue(const std::string& str, const std::vector<GlobalConstants::optionsStruct>& options)
+unsigned int Util::getOptionValue(const std::string& str, const std::vector<GlobalConstants::optionsStruct>& options, const bool& bAllowStringToIntConversion)
 {
     unsigned int value = 0;
     boost::regex expression("^[+-]?\\d+$", boost::regex::perl);
@@ -491,7 +491,7 @@ unsigned int Util::getOptionValue(const std::string& str, const std::vector<Glob
     {
         value = (1 << options.size()) - 1;
     }
-    else if (boost::regex_search(str, what, expression))
+    else if (boost::regex_search(str, what, expression) && bAllowStringToIntConversion)
     {
         value = std::stoi(str);
     }
@@ -590,3 +590,26 @@ void Util::shortenStringToTerminalWidth(std::string& str)
         str.replace(str.begin()+pos1, str.begin()+pos2, "...");
     }
 }
+
+std::string Util::getJsonUIntValueAsString(const Json::Value& json_value)
+{
+    std::string value;
+    try
+    {
+        value = json_value.asString();
+    }
+    catch (...)
+    {
+        try
+        {
+            uintmax_t value_uint = json_value.asLargestUInt();
+            value = std::to_string(value_uint);
+        }
+        catch (...)
+        {
+            value = "";
+        }
+    }
+
+    return value;
+}
