@@ -16,7 +16,7 @@ Website::Website()
 
     curlhandle = curl_easy_init();
     curl_easy_setopt(curlhandle, CURLOPT_FOLLOWLOCATION, 1);
-    curl_easy_setopt(curlhandle, CURLOPT_USERAGENT, Globals::globalConfig.sVersionString.c_str());
+    curl_easy_setopt(curlhandle, CURLOPT_USERAGENT, Globals::globalConfig.curlConf.sUserAgent.c_str());
     curl_easy_setopt(curlhandle, CURLOPT_NOPROGRESS, 1);
     curl_easy_setopt(curlhandle, CURLOPT_NOSIGNAL, 1);
     curl_easy_setopt(curlhandle, CURLOPT_CONNECTTIMEOUT, Globals::globalConfig.curlConf.iTimeout);
@@ -331,7 +331,7 @@ int Website::Login(const std::string& email, const std::string& password)
     if (login_form_html.find("google.com/recaptcha") != std::string::npos)
     {
         std::cout   << "Login form contains reCAPTCHA (https://www.google.com/recaptcha/)" << std::endl
-                    << "Login with browser and export cookies to \"" << Globals::globalConfig.curlConf.sCookiePath << "\"" << std::endl;
+                    << "Try to login later" << std::endl;
         return res = 0;
     }
 
@@ -495,10 +495,7 @@ int Website::Login(const std::string& email, const std::string& password)
             res = 1; // Login was successful
     }
 
-    if (auth_code.empty())
-        res = 0;
-
-    if (res == 1)
+    if (res == 1 && !auth_code.empty())
     {
         std::string token_url = "https://auth.gog.com/token?client_id=" + Globals::galaxyConf.getClientId()
                             + "&client_secret=" + Globals::galaxyConf.getClientSecret()
@@ -506,28 +503,25 @@ int Website::Login(const std::string& email, const std::string& password)
                             + "&redirect_uri=" + (std::string)curl_easy_escape(curlhandle, Globals::galaxyConf.getRedirectUri().c_str(), Globals::galaxyConf.getRedirectUri().size());
 
         std::string json = this->getResponse(token_url);
-        if (json.empty())
-            res = 0;
-        else
+        if (!json.empty())
         {
             Json::Value token_json;
             Json::Reader *jsonparser = new Json::Reader;
             if (jsonparser->parse(json, token_json))
             {
                 Globals::galaxyConf.setJSON(token_json);
-                res = 1;
+                res = 2;
             }
             else
             {
                 std::cerr << "Failed to parse json" << std::endl << json << std::endl;
                 std::cerr << jsonparser->getFormattedErrorMessages() << std::endl;
-                res = 0;
             }
             delete jsonparser;
         }
     }
 
-    if (res == 1)
+    if (res >= 1)
         curl_easy_setopt(curlhandle, CURLOPT_COOKIELIST, "FLUSH"); // Write all known cookies to the file specified by CURLOPT_COOKIEJAR
 
     return res;
@@ -545,7 +539,7 @@ bool Website::IsLoggedIn()
 bool Website::IsLoggedInComplex(const std::string& email)
 {
     bool bIsLoggedIn = false;
-    std::string html = this->getResponse("https://www.gog.com/account/settings/personal");
+    std::string html = this->getResponse("https://www.gog.com/account/settings/security");
     std::string email_lowercase = boost::algorithm::to_lower_copy(email); // boost::algorithm::to_lower does in-place modification but "email" is read-only so we need to make a copy of it
 
     htmlcxx::HTML::ParserDom parser;
